Recherche de site Web

Comment autoriser le port via le pare-feu sur AlmaLinux


firewalld est le programme de pare-feu par défaut préinstallé sur Red Hat Enterprise Linux et ses distributions Linux dérivées, telles qu’AlmaLinux.

Par défaut, le pare-feu est activé, ce qui signifie qu’un nombre très limité de services sont en mesure de recevoir le trafic entrant. C’est une fonctionnalité de sécurité intéressante, mais cela signifie que l’utilisateur doit être suffisamment informé pour configurer le pare-feu chaque fois qu’il installe un nouveau service sur le système, comme HTTPD ou SSH par exemple. Sinon, les connexions à partir d’Internet ne peuvent pas atteindre ces services.

Plutôt que de désactiver complètement le pare-feu sur AlmaLinux, nous pouvons autoriser certains ports à travers le pare-feu, ce qui permet aux connexions entrantes d’atteindre nos services. Dans ce guide, nous allons voir comment autoriser un port à travers le pare-feu sur AlmaLinux. N’hésitez pas à nous suivre, que vous ayez récemment installé AlmaLinux ou que vous ayez migré de CentOS vers AlmaLinux.

Dans ce tutoriel, vous allez apprendre :

  • Comment autoriser un port ou un service à travers le pare-feu sur AlmaLinux
  • Comment recharger le pare-feu pour que les modifications prennent effet
  • Comment vérifier quels ports et services sont ouverts dans le pare-feu
  • Comment fermer un port après l’avoir configuré comme ouvert
  • Exemples de commandes pour autoriser les ports les plus courants via le pare-feu

Autoriser un port à travers le firewall sur AlmaLinux

Comment autoriser un port via le pare-feu sur AlmaLinux

Suivez les instructions étape par étape ci-dessous pour autoriser les ports ou les services via firewalld sur AlmaLinux. Vous verrez également comment vérifier les ports ouverts que firewalld a configurés.

  1. Lors de la vérification des ports de pare-feu ouverts sur RHEL 8/CentOS 8 Linux, il est important de savoir que les ports de pare-feu peuvent être ouverts de deux manières principales et différentes. Tout d’abord, le port du pare-feu peut être ouvert dans le cadre d’un service préconfiguré. Prenons cet exemple où nous ouvrons le port pour HTTP dans la zone publique.

    
    firewall-cmd --zone=public --add-service=http --permanent
    

    Bien sûr, l’ajout du service HTTP à firewalld équivaut à l’ouverture du port 80.

  2. Deuxièmement, les ports peuvent être ouverts directement en tant que ports prédéfinis par l’utilisateur personnalisés. Prenons cet exemple où nous ouvrons le port 8080.

    
    firewall-cmd --zone=public --add-port 8080/tcp --permanent
    

    Étant donné que 8080 n’a pas de service associé, il est nécessaire pour nous de spécifier le numéro de port plutôt qu’un nom de service si nous voulons ouvrir ce port.

  3. Pour vérifier quels ports de service sont ouverts, exécutez la commande suivante.

    
    firewall-cmd --zone=public --list-services
    cockpit dhcpv6-client http https ssh
    

    Les numéros de port pertinents des services ci-dessus (cockpit, DHCP, HTTP, HTTPS et SSH) sont ouverts.

  4. Pour vérifier quels numéros de port sont ouverts, utilisez cette commande.

    
    firewall-cmd --zone=public --list-ports
    20/tcp 8080/tcp
    

    Les ports ci-dessus, 20 et 8080, sont ouverts au trafic entrant.

  5. Une fois que vous avez autorisé vos ports et services à traverser le pare-feu, nous devons recharger firewalld pour que les modifications prennent effet. Toutes les règles avec l’option --permanent feront désormais partie de la configuration d’exécution. Les règles sans cette option seront ignorées.

    
    firewall-cmd --reload
    
  6. Nous pouvons également voir une liste de tous les services et ports ouverts en utilisant l’option --list-all.

    
    firewall-cmd --list-all
    public (active)
      target: default
      icmp-block-inversion: no
      interfaces: ens160
      sources: 
      services: cockpit dhcpv6-client http ssh
      ports: 443/tcp
      protocols: 
      masquerade: no
      forward-ports: 
      source-ports: 
      icmp-blocks: 
      rich rules:
    
  7. Notez que firewalld fonctionne avec des zones. Selon la zone utilisée par votre ou vos interfaces réseau, vous devrez peut-être ajouter votre port autorisé à cette zone particulière. La première étape ci-dessus montre comment ajouter une règle à la zone « publique ». Pour voir les règles de cette zone en particulier, continuez à utiliser la syntaxe --zone=.

    
    firewall-cmd --list-all --zone=public
    public (active)
      target: default
      icmp-block-inversion: no
      interfaces: ens160
      sources: 
      services: cockpit dhcpv6-client http ssh
      ports: 443/tcp
      protocols: 
      masquerade: no
      forward-ports: 
      source-ports: 
      icmp-blocks: 
      rich rules:
    
  8. Si vous devez fermer l’un des ports ouverts précédemment configurés, vous pouvez utiliser la syntaxe de commande suivante. Dans cet exemple, nous fermons le port pour HTTPS.

    
    firewall-cmd --zone=public --permanent --remove-service=https
    

C’est tout ce qu’il y a à faire. Pour en savoir plus sur firewalld et la commande Linux firewall-cmd, consultez notre guide dédié sur l’introduction à firewalld et firewall-cmd.

Exemples de ports courants

Utilisez les commandes ci-dessous comme guide de référence facile pour autoriser certains des services les plus courants à travers le pare-feu sur AlmaLinux.

  1. Autorisez HTTP via le pare-feu.

    
    firewall-cmd --zone=public --add-service=http --permanent
    
  2. Autorisez HTTPS via le pare-feu.

    
    firewall-cmd --zone=public --add-service=https --permanent
    
  3. Autorisez MySQL via le pare-feu.

    
    firewall-cmd --zone=public --add-service=mysql --permanent
    
  4. Autorisez SSH via le pare-feu.

    
    firewall-cmd --zone=public --add-service=ssh --permanent
    
  5. Autorisez le DNS via le pare-feu.

    
    firewall-cmd --zone=public --add-service=dns --permanent
    
  6. Autorisez PostgreSQL via le pare-feu.

    
    firewall-cmd --zone=public --add-service=postgresql --permanent
    
  7. Autorisez telnet via le pare-feu.

    
    firewall-cmd --zone=public --add-service=telnet --permanent
    

Réflexions finales

Dans ce guide, nous avons vu comment autoriser un port ou un service à travers le pare-feu sur AlmaLinux. Cela impliquait l’utilisation de la commande firewall-cmd associée à firewalld, ce qui facilite le processus une fois que nous connaissons la syntaxe correcte à utiliser. Nous avons également vu de nombreux exemples d’autorisation de nombreux services parmi les plus courants à travers le pare-feu. N’oubliez pas de porter une attention particulière à la zone dans laquelle vous appliquez vos nouvelles règles.

Articles connexes: